boundary.storage.shell.adapters.gcs

Google Cloud Storage adapter.

Implements IFileStorage for storing files in Google Cloud Storage (GCS). Suitable for production deployments on Google Cloud requiring scalable object storage.

Google Cloud Storage adapter.

Implements IFileStorage for storing files in Google Cloud Storage (GCS).
Suitable for production deployments on Google Cloud requiring scalable
object storage.
raw docstring

close-gcs-storageclj

(close-gcs-storage storage-record)

Close the GCS Storage client to release resources.

Close the GCS Storage client to release resources.
sourceraw docstring

create-gcs-storageclj

(create-gcs-storage {:keys [bucket project-id prefix public-read? logger]
                     :as config})

Create a Google Cloud Storage adapter.

Required options:

  • :bucket - GCS bucket name
  • :project-id - Google Cloud project id

Optional options:

  • :credentials-path - Path to a service-account JSON key file (if not using Application Default Credentials)
  • :prefix - Key prefix for all objects (default: nil)
  • :public-read? - Make all objects publicly readable (default: false)
  • :logger - Logger instance (optional)
Create a Google Cloud Storage adapter.

Required options:
- :bucket - GCS bucket name
- :project-id - Google Cloud project id

Optional options:
- :credentials-path - Path to a service-account JSON key file (if not using
  Application Default Credentials)
- :prefix - Key prefix for all objects (default: nil)
- :public-read? - Make all objects publicly readable (default: false)
- :logger - Logger instance (optional)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries