Google Cloud Storage adapter.
Implements IFileStorage for storing files in Google Cloud Storage (GCS). Suitable for production deployments on Google Cloud requiring scalable object storage.
Google Cloud Storage adapter. Implements IFileStorage for storing files in Google Cloud Storage (GCS). Suitable for production deployments on Google Cloud requiring scalable object storage.
(close-gcs-storage storage-record)Close the GCS Storage client to release resources.
Close the GCS Storage client to release resources.
(create-gcs-storage {:keys [bucket project-id prefix public-read? logger]
:as config})Create a Google Cloud Storage adapter.
Required options:
Optional options:
Create a Google Cloud Storage adapter. Required options: - :bucket - GCS bucket name - :project-id - Google Cloud project id Optional options: - :credentials-path - Path to a service-account JSON key file (if not using Application Default Credentials) - :prefix - Key prefix for all objects (default: nil) - :public-read? - Make all objects publicly readable (default: false) - :logger - Logger instance (optional)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |